==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/node_cms.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_home_page_editorial'] = 				"home page editorial";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_activities'] = 						"activities";
$lang['hdr_group_library'] = 					"library items";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_files'] = 							"files";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";

//ICONS
$lang['ttl_sticky'] = 							"S";
$lang['ttl_remove'] = 							"R";
$lang['ttl_live'] = 							"L";
$lang['ttl_hold'] = 							"H";
$lang['ttl_pending'] = 							"P";


$lang['txt_sticky'] = 							"sticky";
$lang['txt_all'] = 								"all";
$lang['txt_remove'] = 							"remove";
$lang['txt_live'] = 							"live";
$lang['txt_hold'] = 							"hold";
$lang['txt_pending'] = 							"pending";

?>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/language/1/am_default/node_cms.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_home_page_editorial'] = 				"home page editorial";
$lang['hdr_user_blogs'] = 						"user blogs";
$lang['hdr_group_blogs'] = 						"group blogs";
$lang['hdr_activities'] = 						"activities";
$lang['hdr_group_library'] = 					"group library items";
$lang['hdr_user_library'] = 					"user library items";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_files'] = 							"files";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";

//ICONS
$lang['ttl_sticky'] = 							"S";
$lang['ttl_remove'] = 							"R";
$lang['ttl_live'] = 							"L";
$lang['ttl_hold'] = 							"H";
$lang['ttl_pending'] = 							"P";


$lang['txt_sticky'] = 							"sticky";
$lang['txt_all'] = 								"all";
$lang['txt_remove'] = 							"remove";
$lang['txt_live'] = 							"live";
$lang['txt_hold'] = 							"hold";
$lang['txt_pending'] = 							"pending";

?>
